<?php
/*
Plugin Name: Exclusivo entrada complemento
Plugin URI: https://github.com/sasousuke/exclusivo-entrada-plugin
Description: Plugin de Wordpress para anadir una frase o palabra ante cada titulo de entrada a mostrar
Version: 1.0.3
Author: Ernesto Tur Laurencio
Author URI: https://twitter.com/sasousuke
License: GPLv3
*/

/*
  Por razones de seguridad se recomienda incluir al inicio del codigo en cada fichero fuente
*/
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/*
  Funcion que realiza la modificacion del titulo
*/
function exclusivo_entrada_plugin_cambiar_titulo( $title, $id ) {
    $categories = get_the_category($id);
    $check = false;
    foreach( $categories as $category )
	  if ($category->category_nicename == get_option('exclusivo_entrada_plugin_categoria_value'))
        $check = true;
    if ($check == true)
	  $title = get_option('exclusivo_entrada_plugin_value') . ' '. $title;
    return $title;
}

/*
  Se anade al evento the_title una llamada a la funcion definida
*/
add_filter( 'the_title', 'exclusivo_entrada_plugin_cambiar_titulo', 10, 2 );

/*
  Menu de opciones del plugin
*/
function exclusivo_entrada_plugin_menu (){
	add_menu_page('Ajustes del plugin Exclusivo Entrada Plugin', #Titulo de la pagina
                     'Exclusivo Entrada Plugin',                         #Titulo del menu
                     'administrator',                                    #Rol que puede acceder
                     'exclusivo-entrada-plugin-settings',                #Id de la pagina de opciones
                     'exclusivo_entrada_plugin_page_settings',           #Funcion que visualiza las configuraciones del plugin
                     'dashicons-admin-generic'                           #Icono del menu
	);
}

/*
  Se anade al menu del panel de administracion una entrada referente a las configuraciones
*/
add_action('admin_menu', 'exclusivo_entrada_plugin_menu');

/*
  Funcion que visualiza las configuraciones del plugin
*/
function exclusivo_entrada_plugin_page_settings(){
?>
	<div class="wrap">
		<h2>Configuracion</h2>
		<form method="POST" action="options.php">
			<?php 
				settings_fields('exclusivo-entrada-plugin-settings-group');
				do_settings_sections('exclusivo-entrada-plugin-settings-group'); 
			?>
			<table>
				<tr>
					<td>
					    <label>Palabra(s):&nbsp;</label>
					</td>
					<td>
			            <input 	type="text" 
					            name="exclusivo_entrada_plugin_value" 
					            id="exclusivo_entrada_plugin_value" 
					            value="<?php echo get_option('exclusivo_entrada_plugin_value'); ?>" />
					</td>
				</tr>
				<tr>
					<td>
					    <label>Categor&iacute;a:&nbsp;</label>
					</td>
					<td>
			           <select name="exclusivo_entrada_plugin_categoria_value" width="100%"> 
                             <option value=""><?php echo esc_attr_e( 'Seleccione una', 'textdomain' ); ?></option> 
<?php 
    $categories = get_categories(); 
    foreach ( $categories as $category ) {
     $stringOption = '<option value="' . esc_attr($category->category_nicename).'"';
     if ($category->category_nicename == get_option('exclusivo_entrada_plugin_categoria_value')){
         $stringOption = $stringOption . 'selected="selected"';
     }
     echo $stringOption . '>' . esc_html($category->cat_name). '</option>';
    }
?>
                       </select>
					</td>
				</tr>
			</table>
			<?php submit_button(); ?>
		</form>
	</div>
<?php
}

/*
  Funcion que registra las opciones del formulario en una lista blanca para que puedan ser guardadas
*/
function exclusivo_entrada_plugin_register_value_form_settings(){
       // Para el campo que almacenara el encabezado
	register_setting('exclusivo-entrada-plugin-settings-group',
					 'exclusivo_entrada_plugin_value',
					 'string');
       // Para el campo que almacenara la categoria
	register_setting('exclusivo-entrada-plugin-settings-group',
					 'exclusivo_entrada_plugin_categoria_value',
					 'string');
}
add_action('admin_init','exclusivo_entrada_plugin_register_value_form_settings');
?>